# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/01_csv_bq.ipynb (unless otherwise specified).

__all__ = ['ssb_to_gcs', 'parquet_to_bigquery']

# Cell
import os
import re
import dask.dataframe as dd
from google.cloud import bigquery
from google.oauth2 import service_account
from nbdev.showdoc import *
from .core import clean_column_names

# Cell
def ssb_to_gcs(file: str):
    source = f'https://data.ssb.no/api/v0/dataset/{file}.csv'
    destination = f'gs://datafabrikken/ssb_datasett_{file}.parquet'
    df = dd.read_csv(source, encoding='latin-1',sep=';', blocksize=None).head(10)
    df.columns = [clean_column_names(x) for x in df.columns]
    df.to_parquet(destination, storage_options={'token': TOKEN})
    return destination

# Cell
def parquet_to_bigquery(file,table):
    credentials = service_account.Credentials.from_service_account_file(TOKEN)
    client = bigquery.Client(credentials=credentials, project=PROJECT_NAME)
    job_config = bigquery.LoadJobConfig()
    job_config.source_format = bigquery.SourceFormat.PARQUET
    job = client.load_table_from_uri(file,table,job_config=job_config)

    return job.result().state


# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"clean_column_names": "00_core.ipynb",
         "ssb_to_gcs": "01_csv_bq.ipynb",
         "parquet_to_bigquery": "01_csv_bq.ipynb"}

modules = ["core.py",
           "data.py"]

doc_url = "https://docs.datasett.io/"

git_url = "https://github.com/datafabrikken/pypi/tree/master/"

def custom_doc_links(name): return None



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['datasett']

package_data = \
{'': ['*']}

install_requires = \
['dask==2021.3.1',
 'gcsfs==0.7.2',
 'google-api-core==1.26.3',
 'google-auth-oauthlib==0.4.4',
 'google-auth==1.28.0',
 'google-cloud-bigquery==2.13.1',
 'google-cloud-core==1.6.0',
 'google-cloud-datacatalog==3.1.1',
 'google-cloud-datastore==2.1.0',
 'google-cloud==0.34.0',
 'numpy==1.20.2',
 'pandas==1.2.3',
 'pyarrow>=3.0.0,<4.0.0']

setup_kwargs = {
    'name': 'datasett',
    'version': '0.0.1',
    'description': '',
    'long_description': None,
    'author': 'pbencze',
    'author_email': 'paul@idelab.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '==3.9.2',
}


setup(**setup_kwargs)



# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/00_core.ipynb (unless otherwise specified).

__all__ = ['clean_column_names', 'clean_column_names']

# Cell
#nbdev_comment _all_ = ['clean_column_names']

# Cell
from nbdev.showdoc import *
import pandas as pd
import os
import re

# Cell
def clean_column_names(s):
    return re.sub('[^a-zA-Z ]+','_', s.lower()
        .replace('ø','o')
        .replace('æ','ae')
        .replace('å','aa')).strip()